import 'package:equatable/equatable.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter_webrtc/flutter_webrtc.dart';
import 'package:transmedika_one_to_one_call/webrtc/profile.dart';

/// Base UI Event ///
@immutable
abstract class OneToOneUiUIEvent extends Equatable{
  @override
  List<Object> get props => [];
}

/// class or model for event web socket connect ///
@immutable
class OnConnectToSocket extends OneToOneUiUIEvent {
  OnConnectToSocket({
    required this.host,
    required this.from,
    required this.to,
    required this.isCalling,
    required this.consultationId,
    required this.mySelf,
    required this.other
  });
  final String host;
  final String from;
  final String to;
  final bool isCalling;
  final String consultationId;
  final Profile mySelf;
  final Profile other;
}

/// class or model for event on web socket open ///
@immutable
class OnSocketOpen extends OneToOneUiUIEvent {}

/// class or model for event user accepted call ///
@immutable
class OnCallAccepted extends OneToOneUiUIEvent {}

/// class or model for event user rejected call ///
@immutable
class OnCallRejected extends OneToOneUiUIEvent {}

/// class or model for event user stop call ///
@immutable
class OnStopCall extends OneToOneUiUIEvent {}

/// class or model for event user mute call ///
@immutable
class OnMute extends OneToOneUiUIEvent {}

/// class or model for event user switch camera ///
@immutable
class OnSwitchCamera extends OneToOneUiUIEvent {}

/// class or model for event user enable video during call ///
@immutable
class OnEnableVideo extends OneToOneUiUIEvent {}

/// class or model for event on message web socket ///
@immutable
class OnSocketMessage extends OneToOneUiUIEvent {
  OnSocketMessage({required this.message});
  final String message;
}

/// class or model for event on web socket close ///
@immutable
class OnSocketClose extends OneToOneUiUIEvent {
  OnSocketClose({required this.ex, required this.from});
  final String ex;
  final bool from;
}

/// class or model for event user register to web socket ///
@immutable
class OnRegister extends OneToOneUiUIEvent {}

/// class or model for event local stream ///
@immutable
class OnLocalStream extends OneToOneUiUIEvent {
  OnLocalStream({required this.mediaStream});
  final MediaStream mediaStream;
}

/// class or model for event user remote stream ///
@immutable
class OnAddRemoteStream extends OneToOneUiUIEvent {
  OnAddRemoteStream({required this.mediaStream});
  final MediaStream mediaStream;
}

/// class or model for event user remove remote stream ///
@immutable
class OnRemoveRemoteStream extends OneToOneUiUIEvent {
  OnRemoveRemoteStream({required this.mediaStream});
  final MediaStream? mediaStream;
}

/// class or model for event close session ///
@immutable
class OnCloseSession extends OneToOneUiUIEvent {}